<%inherit file="objectlist.html" /> <%namespace file="base/base.html" import="header, setup_margin_labels" /> <%block name="extra_meta">
${ setup_margin_labels(report.title) } <%block name="after_table"> % if len(report.branch_total) > 1:

### ${ _("Totals by branch") }

${ _("Branch") } | ${ _("Total Quantity") } | ${ _("Total") }
% for branch in report.branch_total:
${ branch } | ${ format_quantity(report.branch_quantity[branch]) } | ${ format_price(report.branch_total[branch]) }
% endfor

% endif